pub(crate) async fn close_client(
__arg0: State<Arc<InternalState>>,
__arg1: Path<SessionCloseClientQuery>,
) -> Result<impl IntoResponse, impl IntoResponse>Expand description
Closes an existing Session listener. The listener must’ve been previously created and bound for the given IP protocol. Once a listener is closed, no more socket connections can be made to it. If the passed port number is 0, listeners on all ports of the given listening IP and protocol will be closed.