pub(crate) struct SessionClientResponse {Show 14 fields
pub target: String,
pub destination: Address,
pub forward_path: RoutingOptions,
pub return_path: RoutingOptions,
pub protocol: IpProtocol,
pub ip: String,
pub port: u16,
pub hopr_mtu: usize,
pub surb_len: usize,
pub active_clients: Vec<String>,
pub max_client_sessions: usize,
pub max_surb_upstream: Option<Bandwidth>,
pub response_buffer: Option<ByteSize>,
pub session_pool: Option<usize>,
}Expand description
Response body for creating a new client session.
Fields
target: StringTarget of the Session.
destination: AddressDestination node (exit node) of the Session.
forward_path: RoutingOptionsForward routing path.
return_path: RoutingOptionsReturn routing path.
protocol: IpProtocolIP protocol used by Session’s listening socket.
ip: StringListening IP address of the Session’s socket.
port: u16Listening port of the Session’s socket.
hopr_mtu: usizeMTU used by the underlying HOPR transport.
surb_len: usizeSize of a Single Use Reply Block used by the protocol.
This is useful for SURB balancing calculations.
active_clients: Vec<String>Lists Session IDs of all active clients.
Can contain multiple entries on TCP sessions, but currently always only a single entry on UDP sessions.
max_client_sessions: usizeThe maximum number of client sessions that the listener can spawn.
This currently applies only to the TCP sessions, as UDP sessions cannot have multiple clients (defaults to 1 for UDP).
max_surb_upstream: Option<Bandwidth>The maximum throughput at which artificial SURBs might be generated and sent to the recipient of the Session.
response_buffer: Option<ByteSize>The amount of response data the Session counterparty can deliver back to us, without us sending any SURBs to them.
session_pool: Option<usize>How many Sessions to pool for clients.