pub(crate) struct SessionConfig {
pub response_buffer: Option<ByteSize>,
pub max_surb_upstream: Option<Bandwidth>,
}Fields
response_buffer: Option<ByteSize>The amount of response data the Session counterparty can deliver back to us, without us sending any SURBs to them.
In other words, this size is recalculated to a number of SURBs delivered to the counterparty upfront and then maintained. The maintenance is dynamic, based on the number of responses we receive.
All syntaxes like “2 MB”, “128 kiB”, “3MiB” are supported. The value must be at least the size of 2 Session packet payloads.
max_surb_upstream: Option<Bandwidth>The maximum throughput at which artificial SURBs might be generated and sent to the recipient of the Session.
On Sessions that rarely send data but receive a lot (= Exit node has high SURB consumption), this should roughly match the maximum retrieval throughput.
All syntaxes like “2 MBps”, “1.2Mbps”, “300 kb/s”, “1.23 Mb/s” are supported.